# Java

The Launchable CLI includes built-in integrations for test runners and build tools that are popular in the Java/JVM ecosystem:

* [Ant](../test-runners/ant.md)
* [Bazel](../test-runners/bazel.md)
* [Gradle](../test-runners/gradle.md)
* [Maven](../test-runners/maven.md)

See each integration's page for instructions to add Launchable to your CI pipeline.

